@@ -41,7 +41,7 @@
 # 
 ###############################################################################
 histDirectional <- function( x, k, p=2, plot.type="default", freq=TRUE,
-                              positive.only=FALSE, report="summary", label.octants=TRUE, 
+                              positive.only=FALSE, report="summary", label.orthants=TRUE, 
                               normalize.by.area=FALSE, ... ) {
 # plot a directional histogram for the d-dimensional data in x
 # Written by John Nolan, 25 Oct. 2014
@@ -103,21 +103,21 @@ if ( plot.type != "none" ) {
     val.max <- max(value)
     cone <- 1:ncones
     if (positive.only) {
-      n.octants <- 1
+      n.orthants <- 1
     } else {
-      n.octants <- 2^d    
+      n.orthants <- 2^d    
     }
-    octant.width <- ncones/n.octants
+    orthant.width <- ncones/n.orthants
     plot(cone,value,type='h',ylab=ylab.string,ylim=c(0,val.max), ...)
-    if (label.octants) {
+    if (label.orthants) {
       plus.minus <- c("+","-")
-      for (i in 1:n.octants) {
+      for (i in 1:n.orthants) {
         y <- ConvertBase(i-1,2,d)
         signs <- (-1)^y
         label <- paste( plus.minus[y+1],collapse="")
-        x.center <- (i-1/2)*octant.width
+        x.center <- (i-1/2)*orthant.width
         text( x.center,val.max, label )
-        abline(v=i*octant.width+1/2,col='red',lty=2)
+        abline(v=i*orthant.width+1/2,col='red',lty=2)
       }
     }
   } else {
@@ -324,13 +324,15 @@ if (plot.type=="index") {
 invisible( list(counts=tally$counts, nrejects=tally$nrejects, nties=tally$nties,
            nx=tally$nx, rel.freq=tally$rel.freq, rel.rejects=tally$rel.rejects, mesh=mesh,
            plot.type=plot.type,report=report)) }
+           # modified 30 Oct 2016 to also return which simplex
 ###############################################################################
 TallyHrep <- function( x, H, report="summary" ) {
 # tally the number of x vectors that are in the simplices specified by H
 #
 # Input values:
-#   x a (d x n) data matrix, columns x[,1],...,x[,n] are data points
-#   H a (d x m x nbins) array, H[,,j] is the H-representation of the j-th simplex
+#   x a (n x d) data matrix, rows x[1,],...,x[n,] are data points (d-dim vectors)
+#   H a (m x (d+2) x nbins) array, H[,,j] is the H-representation of the j-th simplex,
+#      with m=number of linear constraints 
 #   report should be one of c("summary","all","none") and determines the amount of 
 #     reporting for rejects and ties
 
@@ -342,10 +344,12 @@ nbins <- dim(H)[3]
 bin.counts <- rep( 0L, nbins )
 x.counts <- rep( 0L, nrow(x) )
 nties <- 0L
+which.simplex <- rep( 0L, nrow(x) )
 
 # loop through cones, tallying number of data vectors in each cone  
 for (i in 1:nbins) {
   satisfy <- SatisfyHrep( x, H[,,i] )
+  which.simplex[satisfy] <- i
   for (j in satisfy) {
     if (x.counts[j]==0L) {
       bin.counts[i] <- bin.counts[i] + 1L
@@ -371,8 +375,9 @@ if ( (report %in% c("summary","all") ) & ((nties > 0) || (nrejects > 0) ) ){
 }
 
 nx <- nrow(x)
-return( list(counts=bin.counts,nrejects=nrejects,nties=nties,nx=nx,
-             rel.freq=bin.counts/nx,rel.rejects=nrejects/nx) ) }
+return( list( counts=bin.counts, nrejects=nrejects, nties=nties, nx=nx,
+              rel.freq=bin.counts/nx, rel.rejects=nrejects/nx, 
+              which.simplex=which.simplex ) ) }
 ###############################################################################
 HrepCones <- function( S ) {
 # calculate the H-representation for the cones generated by the simplices in S and the origin
