@@ -130,8 +130,8 @@ if (p != 1.0) {
   }
 }
 
-# if !positive.only, rotate & reflect first octant to cover all other
-# octants.  Check for duplicate vertices and edges along axes
+# if !positive.only, rotate & reflect first orthant to cover all other
+# orthants.  Check for duplicate vertices and edges along axes
 if (!positive.only ) {
   # reflect first orthant into all other orthants
   newptr <- rep( 0L, M )     
@@ -1185,8 +1185,11 @@ nS1 <- dim(H1)[3]
 nS2 <- dim(H2)[3]
 for (i2 in 1:nS2) {
   for (i1 in 1:nS1) {
+#cat("IntersectMultipleH:  i1=",i1,"  i2=",i2,"\n")  
+#if((i1==296) & (i2=8)) { print(H1[,,i1]); print(H2[,,i2]) }
     a <- Intersect2SimplicesH( H1[,,i1], H2[,,i2], tessellate=TRUE )
-    #cat("return from Intersect2: a=\n"); print(str(a))
+#if((i1==296) & (i2=8)) { print(a) }
+#cat("return from Intersect2: a=\n"); print(str(a))
     if ( !is.null(a$S) && (dim(a$S)[1]>0) ) {
       m <- dim(a$S)[3]
       index1 <- c(index1,rep(i1,m))
@@ -1195,6 +1198,7 @@ for (i2 in 1:nS2) {
         S <- a$S
       } else {
         S <- abind( S, a$S, force.array=TRUE )    
+#if (dim(S)[3] <= 21 ) { cat("\n*************************************\n  index1=",index1,"\n  index2=",index2,"\n  dim(S)=",dim(S),"\nS=\n"); print(a$S)}
       }  
     }
   }
@@ -1202,12 +1206,14 @@ for (i2 in 1:nS2) {
 return( list( S=S, index1=index1, index2=index2 ) )}
 ##################################################################################
 Intersect2SimplicesH <- function( H1, H2, tessellate=FALSE ) {
-# intersect two arbitrary simplices given by their H-represenations H1 and H2
-# if tessellate=TRUE, the resulting set is tessellated so that we get 
+# intersect two arbitrary simplices given by their H-represenations H1 and H2.
+# Always return the result in H-representation; if tessellate=TRUE, the resulting simplex V 
+# along with the V-representation of it's tessellation S
 #
 # Return a list with fields:
 #   H = H-representation of the intersection simplex
-#   V = vertices (V-rep.) of the intersection simplex (NULL if intersection has zero volume)
+#   V = vertices (V-rep.) of the intersection simplex, which may have more vertices than
+#       desired (V is NULL if the intersection has zero volume)
 #   S = tesselation of the intersection simplex (if tessellate=TRUE)
 #       NULL if tessellate is FALSE or intersection has zero volume
 
@@ -1220,7 +1226,7 @@ if( nrow(H) > n) {
   V <- H2Vrep( H )[,,1] 
   #cat("Intersect2H:  V="); print(V)  
   if (tessellate) {
-    if (nrow(V) == n+1) {  # prevent zero volume case
+    if (nrow(V) > n) {  # prevent zero volume case  CHANGED from nrow(V) == n+1 12 Dec 2016
       new.tess <- geometry::delaunayn( V, options="Qz" )
       S <- array( 0.0, dim=c(n+1,n,nrow(new.tess)) )
       for (k in 1:nrow(new.tess)) {
